@@ -327,6 +327,7 @@ class Backend(Thread, EventGenerator):
         """
         try:
             from zeroconf import ServiceInfo, Zeroconf
+            from platypush.plugins.zeroconf import ZeroconfListener
         except ImportError:
             self.logger.warning('zeroconf package not available, service discovery will be disabled.')
             return
@@ -355,7 +356,8 @@ class Backend(Thread, EventGenerator):
                                          properties=srv_desc)
 
         self.zeroconf.register_service(self.zeroconf_info)
-        self.bus.post(ZeroconfServiceAddedEvent(service_type=srv_type, service_name=srv_name))
+        self.bus.post(ZeroconfServiceAddedEvent(service_type=srv_type, service_name=srv_name,
+                                                service_info=ZeroconfListener.parse_service_info(self.zeroconf_info)))
 
     def unregister_service(self):
         """
